package nckd.base.helper;

import kd.bos.bundle.BosRes;
import kd.bos.cache.CacheFactory;
import kd.bos.cache.TempFileCache;
import kd.bos.exception.BosErrorCode;
import kd.bos.exception.ErrorCode;
import kd.bos.exception.KDException;
import kd.bos.fileservice.FileItem;
import kd.bos.fileservice.FileService;
import kd.bos.fileservice.config.FileServiceConfig;
import kd.bos.fileservice.enums.PreviewParams;
import kd.bos.fileservice.excelpreview.ExcelPreviewFactory;
import kd.bos.fileservice.impl.*;
import kd.bos.fileservice.multiserver.Dispatcher;
import kd.bos.fileservice.multiserver.DispatcherFactory;
import kd.bos.fileservice.path.DecodeFileFactory;
import kd.bos.fileservice.preview.DefaultPreviewServiceImpl;
import kd.bos.fileservice.preview.PreviewService;
import kd.bos.fileservice.utils.*;
import kd.bos.logging.Log;
import kd.bos.logging.LogFactory;
import kd.bos.servicehelper.AttachmentServiceHelper;
import kd.bos.url.UrlService;
import kd.bos.util.FileUtils;
import kd.bos.util.RevProxyUtil;
import kd.bos.util.StringUtils;
import kd.bos.util.resource.Resources;
import org.apache.commons.io.IOUtils;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.CloseableHttpClient;

import java.io.*;
import java.lang.reflect.Method;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.net.URLEncoder;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.*;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import java.util.zip.ZipOutputStream;


public class DefaultPreviewCusServiceImpl extends DefaultPreviewServiceImpl implements PreviewService {
    private static Log logger = LogFactory.getLog(DefaultPreviewCusServiceImpl.class);
    private FileService fileService;


    public DefaultPreviewCusServiceImpl() {
    }

    public void init(FileService fileService) {
        logger.info("DefaultPreviewCusServiceImpl：" + fileService.toString());

        this.fileService = fileService;
    }

    /**
     * WPS预览模式
     * 如返回第三方预览url
     */
    @Override
    public Map<String, Object> previewWPS(String fileName, String path, String userAgent, Map<String, String> config) {
        String ext = fileName.substring(fileName.lastIndexOf(46) + 1);

        //  txt
        if (YunHomeService.isNotNeedDeal(ext)) {
            path = DecodeFileFactory.getDecodeService().getDecodeFilePath(path);
            path = path.replaceAll("//", "/");
            InputStream in = null;
            new HashMap();
            Map<String, Object> previewResult = new HashMap(3);

            long startTime = 0L;
            long endTime = 0L;
            Map result;
            Map<String, String> headerMap = new HashMap();
            if (userAgent != null) {
                headerMap.put("USER-AGENT", userAgent);
            }

            try {
                in = this.fileService.download(path, headerMap, new HashMap());
            } catch (Exception var19) {
                result = ExceptionUtil.setErrorInfo(var19.getMessage());
                previewResult.put(PreviewParams.STATUS.getEnumName(), PreviewParams.ERROR.getEnumName());
                previewResult.put(PreviewParams.RESULT.getEnumName(), result);
                return previewResult;
            }

            previewResult.put(PreviewParams.STATUS.getEnumName(), PreviewParams.NOT_NEED_CHANGE.getEnumName());
            previewResult.put(PreviewParams.RESULT.getEnumName(), in);
            if ("txt".equalsIgnoreCase(ext)) {
                previewResult.put(PreviewParams.CHARSET.getEnumName(), FileUtil.getFilecharsetNew(in));
            }

            return previewResult;
        } else {
            // 需要转换
            logger.info("--------------previewWPS 需要转换， filename：" + fileName + "," + path + "," + userAgent);

            return super.preview(fileName, path, userAgent);
        }
    }

    /**
     * wps预览模式 - 临时文件url预览
     * 如返回第三方预览url
     */
    @Override
    public Map<String, Object> previewFromCacheWPS(String fileName, String path, String userAgent, InputStream cacheIn, Map<String, String> config) {
        logger.info("testpreviewFromCacheWPS...");

       return super.previewFromCache(fileName, path, userAgent, cacheIn);
    }
}
